//********************************************************************
//*** ResourcePool/SQL/RTNULL.t.cc
//*** Copyright (c) 2003-2008 by Markus Winand <mws@fatalmind.com>
//*** $Id: RTNULL.t.cc,v 1.7 2008/04/12 17:02:04 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include <memory>
#include "t/main.hh"
#include "config.h"
#include "ResourcePool/ResourcePool.hh"
#include "ResourcePool/SQL/ResourcePool.hh"

#include "testconfig.cc"

#ifdef HAVE_ORACLE
std::auto_ptr<RP> oci9_p;
#endif
#ifdef HAVE_MYSQL
std::auto_ptr<RP> mysql3_p;
#endif

std::string getLobTable(RP& p) {
#ifdef HAVE_ORACLE
	if (&p == oci9_p.get()) {
		return "create table fatalmind_lob (id numeric not null primary key, val  clob)";
	}
#endif
	return "create table fatalmind_lob (id numeric not null primary key, val  LONGBLOB)";
}

#include "NULL.t.cc"

void INIT_SQL_NULL() {
#ifdef HAVE_ORACLE
	oci9_p.reset(new RP(getFactory("oci9:" + getOracleLogon())));
	test_NULL_init(*oci9_p);
#endif
#ifdef HAVE_MYSQL
	mysql3_p.reset(new RP(getFactory("mysql3:" + getMysqlLogon())));
	test_NULL_init(*mysql3_p);
#endif
}

void TEST_SQL_OCI9_NULL_insert() {
#ifdef HAVE_ORACLE
	test_NULL_insert(*oci9_p);
#endif
}
void TEST_SQL_OCI9_NULL_select() {
#ifdef HAVE_ORACLE
	test_NULL_select(*oci9_p);
#endif
}

void TEST_SQL_OCI9_NULL_lob() {
#ifdef HAVE_ORACLE
	test_NULL_lob(*oci9_p);
#endif
}
void TEST_SQL_OCI9_NULL_numeric() {
#ifdef HAVE_ORACLE
	test_NULL_numeric(*oci9_p);
#endif
}

void TEST_SQL_MYSQL3_NULL_insert() {
#ifdef HAVE_MYSQL
	test_NULL_insert(*mysql3_p);
#endif
}
void TEST_SQL_MYSQL3_NULL_select() {
#ifdef HAVE_MYSQL
	test_NULL_select(*mysql3_p);
#endif
}

void TEST_SQL_MYSQL3_NULL_lob() {
#ifdef HAVE_MYSQL
	test_NULL_lob(*mysql3_p);
#endif
}

void TEST_SQL_MYSQL3_NULL_numeric() {
#ifdef HAVE_MYSQL
	test_NULL_numeric(*mysql3_p);
#endif
}


void CLEANUP_SQL_NULL() { 
#ifdef HAVE_ORACLE
	test_NULL_cleanup(*oci9_p);
#endif
#ifdef HAVE_MYSQL
	test_NULL_cleanup(*mysql3_p);
#endif
}
