//********************************************************************
//*** ResourcePool/oracle/oracleRefType.hh
//*** Copyright (c) 2003-2008 by Markus Winand <mws@fatalmind.com>
//*** $Id: oracleRefType.hh,v 1.19 2008/04/12 17:02:04 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of 
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_ORACLE_ORACLEREFTYPE_HH
#define RESOURCEPOOL_ORACLE_ORACLEREFTYPE_HH

#include <memory>

#ifndef OCI_ORACLE
#include <oci.h>
#endif

#include <string>

namespace fatalmind {
namespace oracle {

class oracleRefType {
	public:
		oracleRefType();
		virtual void* ptr() const = 0;
		virtual sb4   capacity() const = 0;
		virtual ub2   type() const = 0;
		virtual void  start() = 0;
		virtual void  done(const ub4 size, void* ptr) = 0;
		virtual ~oracleRefType();
		dvoid* indptr() const;
		bool isnull() const;
		
//		ub2 len;
		sb2 _ind;
};

template<typename T>
class oracleRefTypeImpl: public oracleRefType {
	public:
		oracleRefTypeImpl(T& val);
		virtual ~oracleRefTypeImpl();

		virtual void* ptr() const;
		virtual sb4   capacity() const;
		virtual ub2   type() const;
		virtual void  start();
		virtual void  done(const ub4 size, void* ptr);
		virtual T&    getValue();
		
	private:
		T& _val;
};

template<>
class oracleRefTypeImpl<std::string>: public oracleRefType {
	public:
		oracleRefTypeImpl(std::string& val);
		virtual ~oracleRefTypeImpl();

		virtual void* ptr() const;
		virtual sb4   capacity() const;
		virtual ub2   type() const;
		virtual void  start();
		virtual void  done(const ub4 size, void* ptr);
	private:
		std::string& _val;
		sb4 _cap;
		std::auto_ptr<char> _buf;
		bool needsreset;
};


} // namespace oracle
} // namespace fatalmind
#endif
