//********************************************************************
//*** ResourcePool/oracle/testconfig.cc
//*** Copyright (c) 2003-2008 by Markus Winand <mws@fatalmind.com>
//*** $Id: testconfig.cc,v 1.13 2008/04/12 17:02:04 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include <stdlib.h>

using namespace fatalmind;

typedef ResourcePool<ResourceType::oracle> RP;

std::string getConnectString() {
	char *cstr = getenv("FATALMIND_RESOURCEPOOL_ORACLE");
	if (cstr != NULL) {
		std::string connect(cstr);
		if (connect.length()) {
			return connect;
		}
	}
	throw fatalmind::SkippedException("No Oracle testdatabase set (use FATALMIND_RESOURCEPOOL_ORACLE)");
}

std::string getSID() {
	char *cstr = getenv("ORACLE_SID");
	if (cstr != NULL) {
		std::string sid(cstr);
		if (sid.length()) {
			return sid;
		}
	}
	throw fatalmind::SkippedException("No Oracle testdatabase set (use ORACLE_SID)");
}

RP::Factory getFactory() {
	return RP::Factory(getConnectString());
}

void drop(RP& p) {
	try {
		RP::Command::SQLExecute sql("drop table hirsch");
		p.execute(sql);
	} catch (...) {
	}
}

void init(RP& p) {
	drop(p);
	RP::Command::SQLExecute sql(
		"create table hirsch (id numeric not null primary key, ukn varchar(255))"
	);
	p.execute(sql);
}

void clear(RP& p) {
	RP::Command::SQLExecute sql("delete from hirsch");
	p.execute(sql);
}

